import axios from 'axios';
import type {
  GenericResponse,
  ILoginInput,
  ILoginResponse,
  ISignUpInput,
  IUserResponse,
} from './types';

const BASE_URL = 'http://localhost:8000/api/';

export const authApi = axios.create({
  baseURL: BASE_URL,
  withCredentials: true,
});

authApi.defaults.headers.common['Content-Type'] = 'application/json';

export const refreshAccessToken = async () => {
  const response = await authApi.get<ILoginResponse>('auth/refresh');
  return response.data;
};

authApi.interceptors.response.use(
  (response) => {
    return response;
  },
  async (error) => {
    const originalRequest = error.config;
    const errMessage = error.response.data.message as string;
    if (
      errMessage.includes('access token expired') &&
      !originalRequest._retry
    ) {
      originalRequest._retry = true;
      await refreshAccessToken();
      return authApi(originalRequest);
    }
    if (errMessage.includes('access token invalid')) {
      document.location.href = '/login';
    }
    return Promise.reject(error);
  }
);

export const signUpUser = async (user: ISignUpInput) => {
  const response = await authApi.post<GenericResponse>('auth/register', user);
  return response.data;
};

export const loginUser = async (user: ILoginInput) => {
  const response = await authApi.post<ILoginResponse>('auth/login', user);
  localStorage.setItem('accessToken', response.data.access_token);
  return response.data;
};

export const verifyEmail = async (verificationCode: string) => {
  const response = await authApi.get<GenericResponse>(
    `auth/verifyemail/${verificationCode}`
  );
  return response.data;
};

export const logoutUser = async () => {
  const response = await authApi.get<GenericResponse>('auth/logout', {
    headers: getAuthHeader(),
  });
  localStorage.removeItem('accessToken');
  return response.data;
};

export const getMe = async () => {
  const response = await authApi.get<IUserResponse>('users/me', {
    headers: getAuthHeader(),
  });
  return response.data;
};
