import { authApi } from './authApi';
import type { GenericResponse, IPostResponse, IPostsResponse } from './types';

export const getAllPosts = async () => {
  const response = await authApi.get<IPostsResponse>('posts');
  return response.data;
};

export const getPost = async (id: string) => {
  const response = await authApi.get<IPostResponse>(`posts/${id}`);
  return response.data;
};

export const createPost = async (formData: FormData) => {
  const response = await authApi.post<IPostResponse>('posts', formData, {
    headers: {
      'Content-Type': 'multipart/form-data',
    },
  });
  return response.data;
};

export const updatePost = async ({
  id,
  formData,
}: {
  id: string;
  formData: FormData;
}) => {
  const response = await authApi.patch<IPostResponse>(`posts/${id}`, formData, {
    headers: {
      'Content-Type': 'multipart/form-data',
    },
  });
  return response.data;
};

export const deletePost = async (id: string) => {
  const response = await authApi.delete<GenericResponse>(`posts/${id}`);
  return response.data;
};
